==> pureadmin_0.3.orig.tar.gz: pureadmin-0.3/src/prefwin.h <==
/* PureAdmin
 * Copyright (C) 2003 Isak Savo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * Preferences management - the GUI-part.
 *
 */
#ifndef __PREFWIN_H__
#define __PREFWIN_H__

typedef struct prefwin_widgets_ {
	GtkWidget *menu_uid, *menu_gid, *home, *encoding;
	GtkWidget *hbox_tip, *btn_create_id;
	GtkWidget *cmd_purepw, *pwfile, *pdbfile;
	GtkWidget *btn_search, *chk_resolve, *btn_home_browse, *btn_encoding_sel;
	GtkWidget *btn_browse_purepw, *btn_browse_pw, *btn_browse_pdb;
	GtkWidget *rdo_syslog, *rdo_custom, *logfile;
	GtkWidget *chk_save_window_geo, *chk_use_system_encoding;
	GtkWidget *chk_use_tray_icon;
} prefwin_widgets;

typedef struct pa_encoding_t_ {
  gchar *realname;
  gchar *label;
} pa_encoding_t;

GtkWidget *pref_init_prefwindow (GtkWidget *parent);

#endif /* __PREFWIN_H__ */

==> pureadmin_0.4.orig.tar.gz: pureadmin-0.4/src/prefwin.h <==
/* PureAdmin
 * Copyright (C) 2003 Isak Savo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * Preferences management - the GUI-part.
 *
 */
#ifndef __PREFWIN_H__
#define __PREFWIN_H__

typedef struct prefwin_widgets_ {
	GtkWidget *menu_uid, *menu_gid, *home, *encoding;
	GtkWidget *hbox_tip, *btn_create_id;
	GtkWidget *cmd_purepw, *pwfile, *pdbfile;
	GtkWidget *btn_search, *chk_resolve, *btn_home_browse, *btn_encoding_sel;
	GtkWidget *btn_browse_purepw, *btn_browse_pw, *btn_browse_pdb;
	GtkWidget *rdo_syslog, *rdo_custom, *logfile;
	GtkWidget *chk_save_window_geo, *chk_use_system_encoding;
	GtkWidget *chk_use_tray_icon, *chk_always_notify;
} prefwin_widgets;

typedef struct pa_encoding_t_ {
  gchar *realname;
  gchar *label;
} pa_encoding_t;

GtkWidget *pref_init_prefwindow (GtkWidget *parent);

#endif /* __PREFWIN_H__ */
